@@ -2,16 +2,19 @@ use crate::software_vault::SoftwareVault;
 use crate::xeddsa::XEddsaVerifier;
 use crate::VaultError;
 use arrayref::array_ref;
+use ockam_core::Result;
+use ockam_core::{async_trait, compat::boxed::Box};
 use ockam_vault_core::{PublicKey, Signature, Verifier, CURVE25519_PUBLIC_LENGTH};
 
+#[async_trait]
 impl Verifier for SoftwareVault {
     /// Verify signature with xeddsa algorithm. Only curve25519 is supported.
-    fn verify(
+    async fn verify(
         &mut self,
         signature: &Signature,
         public_key: &PublicKey,
         data: &[u8],
-    ) -> ockam_core::Result<bool> {
+    ) -> Result<bool> {
         // TODO: Add public key type
         if public_key.as_ref().len() == CURVE25519_PUBLIC_LENGTH && signature.as_ref().len() == 64 {
             let signature_array = array_ref!(signature.as_ref(), 0, 64);
